#include "SimpleExample.h"
#include <QVBoxLayout>

using namespace cubepluginapi;

SimpleExample::SimpleExample() : widget_(nullptr), qlabel_(nullptr), service_(nullptr) {}

bool SimpleExample::cubeOpened(PluginServices* service)
{
    this->service_ = service;

    // Create widget and label
    widget_ = new QWidget();
    qlabel_ = new QLabel("Select an item in the System Tree", widget_);

    QVBoxLayout* layout = new QVBoxLayout();
    layout->addWidget(qlabel_);
    widget_->setLayout(layout);

    // Add tab to Cube GUI
    service_->addTab(cubegui::SYSTEM, this);

    // Connect signal for tree item selection
    auto selectedItems = service_->getSelections(cubegui::SYSTEM);
    if (!selectedItems.isEmpty()) {
        treeItemIsSelected(selectedItems.first());
    }
    return true; // Ensure the method returns a value
}
void SimpleExample::cubeClosed()
{
    delete widget_;
    widget_ = nullptr;
    qlabel_ = nullptr;
    service_ = nullptr;
}

QString SimpleExample::name() const
{
    return "SimpleExamplePlugin";
}

void SimpleExample::version(int& major, int& minor, int& bugfix) const
{
    major = 1;
    minor = 0;
    bugfix = 0;
}

QString SimpleExample::getHelpText() const
{
    return "This plugin displays the name of the selected System Tree item.";
}

QString SimpleExample::label() const
{
    return "Simple Example";
}

QWidget* SimpleExample::widget()
{
    return widget_;
}

void SimpleExample::treeItemIsSelected(TreeItem* item)
{
    if (item)
    {
        qlabel_->setText("Selected item: " + item->getName());
    }
}
